<div>
    <strong>{{title}}</strong> WARNING: this is the inner body of a node in <strong>trickle</strong> layout. This should never be displayed. Check your <code>webcomic.yaml</code> file again.
</div>