{%-if opengraph is defined-%}
<meta property="og:title" content="{{opengraph.title}}">
<meta property="og:site_name" content="{{opengraph.site_name}}">
<meta property="og:description" content="{{opengraph.description}}">
<meta property="og:type" content="comicpanda:webcomic_episode">
<meta property="og:image" content="{{opengraph.image.url}}">
<meta property="og:image:alt" content="{{opengraph.image.alt}}">
<meta property="og:image:width" content="{{opengraph.image.width}}">
<meta property="og:image:height" content="{{opengraph.image.height}}">
<meta name="twitter:card" content="summary_large_image">
{%-endif-%}