<html>
{%- include 'autogenerated_warning.jinja' -%}
    <head>
        {%- include 'opengraph.jinja' -%}
        <meta content="text/html;charset=utf-8" http-equiv="Content-Type">
        <meta content="utf-8" http-equiv="encoding">
        <title>{{head_title}}</title>
        {% if ganalytics is defined %}
            <!-- Google tag (gtag.js) -->
            <script async src="https://www.googletagmanager.com/gtag/js?id={{ganalytics.tracking_id}}"></script>
            <script>
                window.dataLayer = window.dataLayer || [];
                function gtag(){dataLayer.push(arguments);}
                gtag('js', new Date());
                gtag('config', '{{ganalytics.tracking_id}}');
            </script>
        {% endif %}
        {%-block header-%}{%- endblock -%}
    </head>
    <body>
        {%- block boddy -%}{%endblock%}
    </body>
</html>